@@ -193,7 +193,7 @@ void KNutAnalog::setArcColor(int reg, QColor color ) {
   }
 
 
-void KNutAnalog::addArc (float startOfCircle, float endOfCircle, int regColor, bool run) {
+void KNutAnalog::addArc (double startOfCircle, double endOfCircle, int regColor, bool run) {
 
   if (m_countOfColorParts < 5) {
     m_extentOfDye[m_countOfColorParts].start=startOfCircle;
@@ -312,7 +312,7 @@ void KNutAnalog::setDigitalProcesing (int qualityOfPointer, bool run ) {
 
 
 
-void KNutAnalog::setPointer (float pointerValue, bool run ) {
+void KNutAnalog::setPointer (double pointerValue, bool run ) {
   if (m_valueOfPointer != pointerValue) {
     m_valueOfPointer = pointerValue;
     paintPointer();
@@ -339,6 +339,7 @@ void KNutAnalog::slotSetScaleFont(QFont newScaleFont){
 void KNutAnalog::slotSetTextFont(QFont newTextFont){
   m_textFont = newTextFont;
   paintBackGround();
+  paintPointer(); // repaint values if pointer
   m_showBackGround=true;
   m_showPointer=true;
   repaint();
@@ -348,6 +349,7 @@ void KNutAnalog::slotSetAllFont(QFont newAllFont){
   m_scaleFont = newAllFont;
   m_textFont = newAllFont;
   paintBackGround();
+  paintPointer(); // repaint values if pointer
   m_showBackGround=true;
   m_showPointer=true;
   repaint();
@@ -424,7 +426,7 @@ void KNutAnalog::paintPointer ( void ) {
 }
 
 
-void KNutAnalog::paintPointerSlowly ( float position, int centerX , int centerY, int widthOfCircle) {
+void KNutAnalog::paintPointerSlowly ( double position, int centerX , int centerY, int widthOfCircle) {
   QPainter paint;
 
   QImage myImage; //big image
@@ -468,7 +470,7 @@ void KNutAnalog::paintPointerSlowly ( float position, int centerX , int centerY,
 
 
 
-void KNutAnalog::paintPointerFastly (float position) {
+void KNutAnalog::paintPointerFastly (double position) {
   QPainter paint;
   double uhel;
 
@@ -504,14 +506,16 @@ void KNutAnalog::paintPointerFastly (float position) {
 
 
 void KNutAnalog::paintPartOfCircle ( QPainter *paint, int centerX , int centerY, int widthOfCircle ) {
-  float Astart, Aend;
+  double Astart, Aend;
 
   // pocitani uhlu
   //nula je ve 3 hodiny
   // prirustek je kladny proti smeru hod rucicek
 
-  float extent = m_topLimit-m_bottomLimit; //rozsah
-  float jednotka = (m_angleOfViewer/extent);
+  //int extent = m_topLimit-m_bottomLimit; //rozsah
+//  double extent = m_topLimit-m_bottomLimit; //rozsah
+//  double jednotka = ((double)m_angleOfViewer/extent);
+  double jednotka = ((double)m_angleOfViewer/(m_topLimit-m_bottomLimit));
   bool painted = false;
 
 //  int smerMK = (-1)*m_direction;
@@ -546,7 +550,7 @@ void KNutAnalog::paintScale ( QPainter *paint , int centerX , int centerY, int w
 
   paint->translate( centerX, centerY );
 
-  float stupne = smer_stup * (m_angleOfViewer/(m_countOfParts*(m_countOfSubParts)));
+  double stupne = smer_stup * (m_angleOfViewer/(m_countOfParts*(m_countOfSubParts)));
 
   // nakresleni prvni linky
   //paints of the first line
@@ -793,9 +797,9 @@ void KNutAnalog::paintScaleNumbers ( QPainter *paint ) {
   //paintig of scaleNumbers
 
   int poz_x, poz_y, r_vyska, r_sirka;
-  float posun, angle;
+  double posun, angle;
 
-  float upi = 0.0174532;
+  double upi = 0.0174532;
   int smer_st = -m_direction;
 
   paint->save();  // ulozime
@@ -805,7 +809,7 @@ void KNutAnalog::paintScaleNumbers ( QPainter *paint ) {
 
   QFontMetrics fm = paint->fontMetrics();
   r_vyska = ((fm.ascent()) / 2);
-  posun = ((float)(m_topLimit-m_bottomLimit))/m_countOfParts;
+  posun = ((double)(m_topLimit-m_bottomLimit))/m_countOfParts;
   for (int i=0; i<=(m_countOfParts);i++) {
     cislo.sprintf( "%3.0f",m_bottomLimit+i*posun);
     cislo=cislo.stripWhiteSpace();
@@ -867,7 +871,7 @@ void KNutAnalog::paintText ( QPainter *paint ) {
 
 
 
-void KNutAnalog::paintValueOfPointer ( QPainter *p, float value) {
+void KNutAnalog::paintValueOfPointer ( QPainter *p, double value) {
 
   QString cislo;
   cislo.sprintf( "%5.1f",value);
