@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Sep 24 2001
     copyright            : (C) 2003 by Daniel Prynych
-    email                : Daniel.Prynych@alo.cz
+    email                : Daniel@prynych.cz
  ***************************************************************************/
 
 /***************************************************************************
@@ -36,8 +36,8 @@ namespace knc {
   const int DefaultInputVoltage = 230;
   const int DefaultInputFrequency = 50;
 
-  const int NumberOfVars = 10; // how many variables we can measure //  kolik promenych muzeme merit 
   const int NumberOfTypes = 14; // count types of variables //  pocet typu promenych (none,utility ....)
+  const int NumberOfVars = NumberOfTypes -1; // how many variables we can measure //  kolik promenych muzeme merit 
 
   enum {VarNone,VarUtility,VarBattPct,VarUpsTemp,VarAcfreq,VarLoadPct,VarAmbTemp,VarAmbHumid,VarBattVolt,VarOutVolt,VarCurrent,VarOutFreq,VarBattTemp,VarBattCurrent};
 
