@@ -38,12 +38,12 @@
 
 //#include <iostream>
 
-KNutDock::KNutDock(struct upsInfo* tActiveUpsInfo, SettingDataDef* tSettingData, KNutUpsData* tUpsRecords){
+KNutDock::KNutDock(KNutVarData::upsInfoDef* activeUpsInfo, KNutVarData::SettingDataDef* settingData, KNutUpsData* upsRecords){
   QString valueName;
 
-  m_settingData = tSettingData;
-  m_upsRecords = tUpsRecords;
-  m_activeUpsInfo = tActiveUpsInfo;
+  m_settingData = settingData;
+  m_upsRecords = upsRecords;
+  m_activeUpsInfo = activeUpsInfo;
 
 //saves backgroundcolor of kicker  
   backgroundColor = paletteBackgroundColor();
@@ -491,14 +491,14 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
   QToolTip::add(this,text);
  }
 
- 
- 
+
+
 /*********************************************************************************************/
 /*                                                                                           */
 /*                         PRIVATE SLOTS                                                     */
 /*                                                                                           */
 /*********************************************************************************************/
- 
+
  void KNutDock::slotShowMyAbout() {
   KAboutApplication *dialog;
 
