@@ -30,11 +30,11 @@
 
 
 KNutInstComms::KNutInstComms(QString* userName, QString* userPassword, const QString uName, const QString password, KNutNet* const upsNet, QWidget* parent,  const char* name, const bool modal)
-: KDialogBase(Plain, i18n("Instant commands"),Ok|Cancel,Ok, parent, name, modal, true), m_myUpsNet(upsNet),m_oldUserName(userName), m_oldUserPassword(userPassword)  {
-  upsIComm myStructIComm;
+: KDialogBase(Plain, i18n("Instant commands"),Ok|Cancel,Ok, parent, name, modal, true), m_upsNet(upsNet),m_oldUserName(userName), m_oldUserPassword(userPassword)  {
+  upsICommDef upsIComm;
 
 
-   if (m_myUpsNet->getState() != KNutNet::Connected) { // no connection - no instant commnads
+   if (m_upsNet->getState() != KNutNet::Connected) { // no connection - no instant commnads
      KNutVarData::showError (KNutNet::NotConnection);
      m_upsConnectOk=false;
      }
@@ -85,11 +85,11 @@ KNutInstComms::KNutInstComms(QString* userName, QString* userPassword, const QSt
 
     topLayout->addStretch(10);
 
-   //naplnime ComboBox
-    int n = m_myUpsNet->readNumberComms()+1;
+   //loads ComboBox
+    int n = m_upsNet->readNumberComms()+1;
     for (int i =1; i < n ; i++) { // for se testuje na zacatku pokud je n < 1 neprovede se ani jednou
-      if (!m_myUpsNet->readIComm(i, myStructIComm))
-        m_instCommBox->insertItem(myStructIComm.upsCommName);
+      if (!m_upsNet->readIComm(i, upsIComm))
+        m_instCommBox->insertItem(upsIComm.upsCommName);
       }
     }
   }
@@ -105,7 +105,7 @@ void KNutInstComms::slotOk() {
   if (((*m_oldUserName) == "") && ((*m_oldUserPassword) == "")) {
     // prvni propojeni nastavime jmeno a heslo
     //for the first connection we have to set name and password
-    if (!( error = m_myUpsNet->instantCommand(m_instCommBox->currentText(),m_lineEditName->text(),m_lineEditPassword->text(),false))) {
+    if (!( error = m_upsNet->instantCommand(m_instCommBox->currentText(),m_lineEditName->text(),m_lineEditPassword->text(),false))) {
       (*m_oldUserName) = m_lineEditName->text();
       (*m_oldUserPassword) = m_lineEditPassword->text();
       accept();
@@ -115,7 +115,7 @@ void KNutInstComms::slotOk() {
     // for other connection name and password are not setted
     if (((*m_oldUserName) == m_lineEditName->text()) && ((*m_oldUserPassword) == m_lineEditPassword->text())) {
       // jen posleme prikaz // sends command only
-      if (!( error = m_myUpsNet->instantCommand(m_instCommBox->currentText(),m_lineEditName->text(),m_lineEditPassword->text(),true))) accept();
+      if (!( error = m_upsNet->instantCommand(m_instCommBox->currentText(),m_lineEditName->text(),m_lineEditPassword->text(),true))) accept();
       }
 // az v pristi verzi
 //    else
