@@ -49,6 +49,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+#include <iostream>
+
 
 
 extern const char *nameUpsVars1[];
@@ -58,12 +60,14 @@ const char *descrOfConnection = I18N_NOOP("test of conection from 5");
 
 
 
-KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tActiveUpsInfo, SettingDataDef* tSettingData, KNutUpsData* tUpsRecords, KNutVarData* tAnalogRecords, QWidget* parent, const char *name) : KMainWindow(parent, name),
+KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, KNutVarData::upsInfoDef* tActiveUpsInfo, KNutVarData::SettingDataDef* tSettingData, KNutUpsData* tUpsRecords, KNutVarData* tAnalogRecords, QWidget* parent, const char *name) : KMainWindow(parent, name),
                    m_listKNutEvent(tListKNutEvent), m_activeUpsInfo(tActiveUpsInfo),m_settingData (tSettingData),
                    m_upsRecords(tUpsRecords), m_analogRecords (tAnalogRecords) {
 
 
 
+  m_settingData->activatedMainWindow=true; //information about state of mainWindow
+
   initVars();
   initStatusBar();
   initAction();
@@ -177,7 +181,7 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
 
 
 //qDebug ("KNutMainWindow::setConfig");
-  VarStrucDef analogMemberData;
+  KNutVarData::VarStrucDef analogMemberData;
   bool repaintVoltagePanels = false;
   bool repaintFrequencyPanels = false;
   bool repaintAllPanels = false;
@@ -603,11 +607,13 @@ void KNutMainWindow::slotShowStatusBar(void) {
   }
 
 void KNutMainWindow::slotDescription(void) {
+
   if (m_descriptionAction->isChecked()) {
     if (!m_activeUpsInfo->upsNet->isDescription()) m_activeUpsInfo->upsNet->getDescription();
     m_settingData->useDescription=true;
     }
   else m_settingData->useDescription=false;
+  emit saveConf();
   }
 
 
@@ -640,6 +646,7 @@ void KNutMainWindow::slotChangeRWVars ( QString ) {
 
 void KNutMainWindow::closeEvent( QCloseEvent *e ){
 
+  m_settingData->activatedMainWindow=false; //information about state of mainWindow
   e->accept();
   }
 
