@@ -25,7 +25,7 @@
 
 #include <unistd.h>  // for function sleep
 
-#include <iostream>
+//#include <iostream>
 
 
 
@@ -38,6 +38,9 @@
 KNutNet::KNutNet (const QString upsAddress, const QString upsName, const unsigned short port, unsigned int countRepeat, const unsigned  int delay)
         : QObject(), m_upsAddress(upsAddress), m_upsName(upsName), m_countRepeat(countRepeat), m_port(port), m_delay(delay)  {
 
+
+//qDebug ("KNutNet::KNutNet");
+
   m_state = Idle;  //idle is value
   m_numberVars = 0;
   m_numberRWVars = 0;
@@ -370,24 +373,24 @@ int KNutNet::readNumberComms (void) {
   }
 
 
-int KNutNet::readIComm (const int seqNumber, struct upsIComm& iComm) {
+int KNutNet::readIComm (const int seqNumber, upsICommDef& upsIComm) {
   m_error =0;
   if (m_state == Connected) {
     if ((seqNumber < 1) || ((unsigned int)seqNumber > m_listIComms.size())) {
       m_error=CommNotFind;
       return m_error;
       }
-    iComm = m_listIComms[seqNumber-1];
+    upsIComm = m_listIComms[seqNumber-1];
     return 0;
     }
   else return NotConnection;
-  }  
+  }
 
 
-int KNutNet::readVars (const QString name, struct upsVar& allVar) {
+int KNutNet::readVars (const QString name, struct upsVarDef& allVar) {
   m_error =0;
   if (m_state == Connected) {
-      QValueVector<upsVar>::const_iterator it;
+      QValueVector<upsVarDef>::const_iterator it;
     for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
        if ((*it).upsVarName == name) {
          allVar = (*it);
@@ -400,12 +403,12 @@ int KNutNet::readVars (const QString name, struct upsVar& allVar) {
   else return NotConnection;
   }
 
-  int KNutNet::readVars (const int seqNumber, struct upsVar& allVar, const typeOfVar typVar) {
+  int KNutNet::readVars (const int seqNumber, struct upsVarDef& allVar, const typeOfVar typVar) {
 
   m_error =0;
   if (m_state == Connected) {
     int n = 1;
-    QValueVector<upsVar>::const_iterator it;
+    QValueVector<upsVarDef>::const_iterator it;
 
     for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
       if ((typVar== AllVars) || ((typVar==ROVars) && ((*it).upsVarType)) ||
@@ -428,7 +431,7 @@ QString KNutNet::readStringVar (const QString name) {
 
   m_error =0;
   if (m_state == Connected) {
-      QValueVector<upsVar>::const_iterator it;
+      QValueVector<upsVarDef>::const_iterator it;
     for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
       if ((*it).upsVarName == name) return (*it).upsValue;
       }
@@ -445,7 +448,7 @@ QString KNutNet::readEnumValueVar (const QString name, const int valueNumber) {
   if (m_state == Connected) {
 //    #if defined  (KDE_VERSION_MAJOR)
 //      #if KDE_VERSION_MAJOR >= 3
-        QValueVector<upsVar>::const_iterator it;
+        QValueVector<upsVarDef>::const_iterator it;
 //      #else
 //        QValueList<upsVar>::ConstIterator it;
 //      #endif
@@ -497,7 +500,7 @@ int KNutNet::existName ( const QString name ) {
 
   m_error =0;
   if (m_state == Connected) {
-        QValueVector<upsVar>::const_iterator it;
+        QValueVector<upsVarDef>::const_iterator it;
     for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
       if ((*it).upsVarName == name) return 0;
       }
@@ -815,7 +818,7 @@ int KNutNet::parseLine(QString& line, QString& upsName ,QString& varName, QStrin
             return NONE;
           default:
             return NONE;
-          }  
+          }
       }
     }
   }
@@ -933,7 +936,7 @@ int KNutNet::getUpsData (const QCString sBuffer, QString& rBuffer, const QCStrin
 
 
     void KNutNet::setRWVars (const QString varName, const bool valueType, const int varMax, QValueVector<QString>* enumValues) {
-      QValueVector<upsVar>::iterator it;
+      QValueVector<upsVarDef>::iterator it;
 
    for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
      if ((*it).upsVarName == varName) {
@@ -946,24 +949,26 @@ int KNutNet::getUpsData (const QCString sBuffer, QString& rBuffer, const QCStrin
     }
   }
 
-void KNutNet::upsSetType (struct upsVar& uVar, const QString name, const QString value) {
+void KNutNet::upsSetType (struct upsVarDef& upsVar, const QString name, const QString value) {
+
   if (((m_nutVariables = 2) && (name == "STATUS")) || ((m_nutVariables = 2) && (name == "ups.status")))
-    uVar.upsVarActivate=true;
-  else uVar.upsVarActivate=false;
-  uVar.upsVarName = name;
-  uVar.upsVarType=true;
-  uVar.upsValueType=true;
-  uVar.upsVarMax=0;
-  uVar.upsValue=value;
-  uVar.upsDescription="";
-  uVar.upsEnumValues=0L;
+    upsVar.upsVarActivate=true;
+  else upsVar.upsVarActivate=false;
+
+  upsVar.upsVarName = name;
+  upsVar.upsVarType=true;
+  upsVar.upsValueType=true;
+  upsVar.upsVarMax=0;
+  upsVar.upsValue=value;
+  upsVar.upsDescription="";
+  upsVar.upsEnumValues=0L;
 }
 
 
 void KNutNet::deleteVars (void) {
 //  #if defined  (KDE_VERSION_MAJOR)
 //    #if KDE_VERSION_MAJOR >= 3
-      QValueVector<upsVar>::iterator it;
+      QValueVector<upsVarDef>::iterator it;
 //    #else
 //      QValueList<upsVar>::Iterator it;
 //    #endif
@@ -1014,8 +1019,8 @@ int KNutNet::getDescription1 (bool always) {
     QCString  inBuffer;
     QString  outBuffer;
 
-     QValueVector<upsVar>::iterator itv;
-     QValueVector<upsIComm>::iterator itc;
+     QValueVector<upsVarDef>::iterator itv;
+     QValueVector<upsICommDef>::iterator itc;
      for (itv = m_listVars.begin(); itv != m_listVars.end(); itv++) {
       //nacteme promenou
       inBuffer = "VARDESC " + (*itv).upsVarName + "\n";
@@ -1053,8 +1058,8 @@ int KNutNet::getDescription2 (bool always) {
     int typeValue;
     int lenString;
 
-     QValueVector<upsVar>::iterator itv;
-     QValueVector<upsIComm>::iterator itc;
+     QValueVector<upsVarDef>::iterator itv;
+     QValueVector<upsICommDef>::iterator itc;
      for (itv = m_listVars.begin(); itv != m_listVars.end(); itv++) {
       //nacteme promenou
       inBuffer = "GET DESC " + m_upsName + " " + (*itv).upsVarName+"\n";
@@ -1125,8 +1130,8 @@ int KNutNet::getUpsVars1 ( void) {
   QCString  inBuffer;
   QString  outBuffer;
   QString  varOutBuffer;
-  struct upsVar uVars;
-  upsIComm uIComm;
+  upsVarDef upsVar;
+  upsICommDef upsIComm;
 
   // init vars and lists
   if (!m_upsName.isEmpty()) { // pokud upsName neni je vzdy nastaveno na null
@@ -1163,8 +1168,8 @@ int KNutNet::getUpsVars1 ( void) {
           if ((word.length() > 0) && word.startsWith("@")) break;
           default:
           // pridame polozku do tabulky
-          upsSetType(uVars, word);
-          m_listVars.push_back(uVars);
+          upsSetType(upsVar, word);
+          m_listVars.push_back(upsVar);
           m_numberVars++;
           break;
           }
@@ -1370,9 +1375,9 @@ int KNutNet::getUpsVars1 ( void) {
           if ((word.length() > 0) && word.startsWith("@")) break;
           default:
           // Zpracujeme polozku v tabulky
-          uIComm.upsCommName=word;
-          uIComm.upsDescription="";
-          m_listIComms.push_back(uIComm);
+          upsIComm.upsCommName=word;
+          upsIComm.upsDescription="";
+          m_listIComms.push_back(upsIComm);
           m_numberIComms++;
           break;
           }
@@ -1390,8 +1395,8 @@ int KNutNet::getUpsVars2 ( void) {
   QCString  inBuffer;
   QString  outBuffer;
   QString  varOutBuffer;
-  struct upsVar uVars;
-  upsIComm uIComm;
+  upsVarDef upsVar;
+  upsICommDef upsIComm;
   int key;
   int typeValue;
   int lenString;
@@ -1412,7 +1417,7 @@ int KNutNet::getUpsVars2 ( void) {
         break;
         case VAR:
          if (beginList ) {
-           upsSetType(uVars, varName, value);
+           upsSetType(upsVar, varName, value);
 
            if (varName == "ups.status") genStatusFlags(value);
            inBuffer = "GET TYPE " + m_upsName + " " + varName +"\n";
@@ -1421,10 +1426,10 @@ int KNutNet::getUpsVars2 ( void) {
              switch (key) {
                case TYPE:
                 if (typeValue & RW_FLAG) {
-                  uVars.upsVarMax = 0;
-                  uVars.upsEnumValues=0L;
+                  upsVar.upsVarMax = 0;
+                  upsVar.upsEnumValues=0L;
                   if (typeValue & ENUM_FLAG) {
-                    uVars.upsValueType=false;
+                    upsVar.upsValueType=false;
                     // nacteme enumValues
                     inBuffer = "LIST ENUM " + m_upsName + " " + varName +"\n";
                     if (!(m_error=getUpsData (inBuffer,varOutBuffer,"END LIST ENUM"))) {
@@ -1438,7 +1443,7 @@ int KNutNet::getUpsVars2 ( void) {
                             varMax=0;
                                  enumString = new QValueVector<QString>;
                             enumString->clear();
-                            uVars.upsEnumValues=enumString;
+                            upsVar.upsEnumValues=enumString;
                           break;
                           case ENUM:
                             if (beginList ) {
@@ -1453,7 +1458,7 @@ int KNutNet::getUpsVars2 ( void) {
                             m_error=UnknownAnswer;
                           return m_error;
                           case END_LIST_ENUM:
-                          uVars.upsVarMax=varMax;
+                          upsVar.upsVarMax=varMax;
                           break;
                           }
                         }
@@ -1461,10 +1466,10 @@ int KNutNet::getUpsVars2 ( void) {
                     }
                   else {
                     // Vse co nenini ENUM je STRING
-                    uVars.upsValueType=true;
-                    uVars.upsVarMax=lenString;
+                    upsVar.upsValueType=true;
+                    upsVar.upsVarMax=lenString;
                     }
-                  uVars.upsVarType=false;
+                  upsVar.upsVarType=false;
                   m_numberRWVars++;
                   }
                  break;
@@ -1477,7 +1482,7 @@ int KNutNet::getUpsVars2 ( void) {
                }
              }
            else { return m_error; }
-           m_listVars.push_back(uVars);
+           m_listVars.push_back(upsVar);
            m_numberVars++;
            }
           break;
@@ -1516,9 +1521,9 @@ int KNutNet::getUpsVars2 ( void) {
         case CMD:
          if (beginList ) {
            // Zpracujeme polozku v tabulky
-           uIComm.upsCommName=varName;
-           uIComm.upsDescription="";
-           m_listIComms.push_back(uIComm);
+           upsIComm.upsCommName=varName;
+           upsIComm.upsDescription="";
+           m_listIComms.push_back(upsIComm);
            m_numberIComms++;
            }
          break;
@@ -1543,7 +1548,7 @@ int KNutNet::getUpsValues1 (const bool allVars ) {// allVars = true vse; allVars
     QString endChar;
     QCString  inBuffer;
     QString  outBuffer;
-    QValueVector<upsVar>::iterator it;
+    QValueVector<upsVarDef>::iterator it;
 
   // Nacte hodnotu promenych
   // reads value of variables
@@ -1647,7 +1652,7 @@ int KNutNet::getUpsValues2 (const bool allVars ) {// allVars = true vse; allVars
   // reads value of variables
   QCString  inBuffer;
   QString  outBuffer;
-  QValueVector<upsVar>::iterator it;
+  QValueVector<upsVarDef>::iterator it;
 
   emit getVarDesc (m_numberVars, 0);
    int numberVar  = 0;
@@ -1742,7 +1747,7 @@ int KNutNet::sendComm (const QString command, const QString arg1, const QString
 int KNutNet::activate ( const QString name, const bool setActivate  ) {
   m_error =0;
   if (m_state == Connected) {
-    QValueVector<upsVar>::iterator it;
+    QValueVector<upsVarDef>::iterator it;
     for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
       if ((*it).upsVarName == name) {
         (*it).upsVarActivate = setActivate;
@@ -1758,7 +1763,7 @@ int KNutNet::activate ( const QString name, const bool setActivate  ) {
 int KNutNet::activateAll ( const bool setActivate  ) {
   m_error =0;
   if (m_state == Connected) {
-    QValueVector<upsVar>::iterator it;
+    QValueVector<upsVarDef>::iterator it;
     for (it = m_listVars.begin(); it != m_listVars.end(); it++) {
       (*it).upsVarActivate = setActivate;
       }
@@ -1849,13 +1854,13 @@ void KNutNet::slotConnectionError(int error) {
     }
   if (error == QSocket::ErrConnectionRefused) {
     error = ConnectionRefused;
-    std::cout << "--KNutNet::connection error ErrConnectionRefused " << QSocket::Idle << " - " << error << std::endl;
+//    std::cout << "--KNutNet::connection error ErrConnectionRefused " << QSocket::Idle << " - " << error << std::endl;
     emit connectionError(error);
     return;
     }
   if (error ==   QSocket::ErrSocketRead) {
     error = SocketReadErr;
-    std::cout << "--KNutNet::connection error QSocket::ErrSocketRead " << error << std::endl;
+//    std::cout << "--KNutNet::connection error QSocket::ErrSocketRead " << error << std::endl;
     emit connectionError(error);
     return;
     }
