@@ -3,7 +3,7 @@
                              -------------------
     begin                : Ne led 12 2003
     copyright            : (C) 2003 by Daniel Prynych
-    email                : Daniel.Prynych@alo.cz
+    email                : Daniel@prynych.cz
  ***************************************************************************/
 
 /***************************************************************************
@@ -32,7 +32,7 @@
 #include <qvaluevector.h>
 
 
-  struct upsVar {
+  struct upsVarDef {
     QString upsVarName;
     bool upsVarActivate;
     bool upsVarType;       // typ true(1) RO -  false (0) RW (muzeme menit)
@@ -46,7 +46,7 @@
     };
 
 
-   struct upsIComm {
+   struct upsICommDef {
     QString upsCommName;
     QString upsDescription;
     };
@@ -191,7 +191,7 @@ public:
     RW_FLAG = 1,
     ENUM_FLAG = 2,
     STRING_FLAG = 4
-    };  
+    };
 
 
 
@@ -352,7 +352,7 @@ bool switchedToTCP ( void );
  **/
   int getDescription (bool always = false);
 
-  
+
 /**
  * Provede okamzity prikaz.
  * Vraci 0 pokud provedeni skoncilo v poradku jinak kod chyby.
@@ -413,11 +413,11 @@ bool switchedToTCP ( void );
  * Pri chybe vrati kod chyby
  *
  * @param seqNumber Udava cislo promene.
- * @param upsIComm Je struktura.
+ * @param upsIComm Je struktura upsICommDef.
  *
  * @since  0.6
  **/
-  int readIComm (const int seqNumber, struct upsIComm& iComm);
+  int readIComm (const int seqNumber, upsICommDef& upsIComm);
 
 
 /**
@@ -428,7 +428,7 @@ bool switchedToTCP ( void );
  *
  * @since  0.6
  **/
-  int readVars (const QString name, struct upsVar& allVar);
+  int readVars (const QString name, struct upsVarDef& allVar);
 
 
 /**
@@ -440,7 +440,7 @@ bool switchedToTCP ( void );
  *
  * @since  0.6
  **/
-  int readVars (const int seqNumber, struct upsVar& allVar, const typeOfVar typVar = AllVars);
+  int readVars (const int seqNumber, struct upsVarDef& allVar, const typeOfVar typVar = AllVars);
 
 
 /**
@@ -756,7 +756,7 @@ int getFirstUpsName (QString& firstUpsName);
 /**
  * @internal
  */
-void upsSetType (struct upsVar& uVar, const QString name, const QString value = "");
+void upsSetType (struct upsVarDef& upsVar, const QString name, const QString value = "");
 
 /**
  * @internal
@@ -773,7 +773,7 @@ void upsSetType (struct upsVar& uVar, const QString name, const QString value =
  * @internal
  */
  int upsOldTranslateError (const QString string);
-  
+
 
 /**
  * @internal
@@ -857,8 +857,8 @@ private:
 
   QMutex m_getUpsDataMutex;
 
-  QValueVector<upsVar> m_listVars;
-  QValueVector<upsIComm> m_listIComms;
+  QValueVector<upsVarDef> m_listVars;
+  QValueVector<upsICommDef> m_listIComms;
 
 /********* Pomocne promenne ***********/
   int m_posChar;
