@@ -26,12 +26,6 @@
 #include <qscrollview.h>
 
 
-  struct analogPanelsRecord {
-    int scaleEnd[knc::NumberOfVars];
-    int scaleStart[knc::NumberOfVars];
-    KNutAnalog* upsAnalogs[knc::NumberOfVars];
-    };
-
 class QLabel;
 class QFont;
 
@@ -46,13 +40,13 @@ public:
  * Konstruktor
  *
  * Param taPanelPalette je paleta pozadi subpanelu MERAKU !!!
- * @param tActiveUpsInfo ukazatel na data o aktivni UPS
- * @param tSettingData ukazatel na zakladni data programu (barvy pozadi, mezikruzi, rucicky ... ,fonty atd )
- * @param tAnalogRecords ukazatel na tridu ktera pracuje s daty o upsekach
+ * @param activeUpsInfo ukazatel na data o aktivni UPS
+ * @param settingData ukazatel na zakladni data programu (barvy pozadi, mezikruzi, rucicky ... ,fonty atd )
+ * @param analogRecords ukazatel na tridu ktera pracuje s daty o upsekach
  *
  * @since  0.2
  **/
-  KNutPanelMeter(QPalette taPanelPalette, struct upsInfo* tActiveUpsInfo,SettingDataDef* tSettingData, KNutVarData* tAnalogRecords, QWidget *parent=0, const char *name=0);
+  KNutPanelMeter(QPalette aPanelPalette, KNutVarData::upsInfoDef* activeUpsInfo, KNutVarData::SettingDataDef* settingData, KNutVarData* analogRecords, QWidget *parent=0, const char *name=0);
 
 /**
  * Destruktor
@@ -187,14 +181,23 @@ private:
   static const int MaxBattVolt = 350;   //   max battery.voltage
   static const int MaxCurrent = 50;    //     max output.current
   static const int MaxBattCurrent = 50;   //  max battery.current
+/************ private struct ************************/
+
+  struct analogPanelRecordsDef {
+    int scaleEnd[knc::NumberOfVars];
+    int scaleStart[knc::NumberOfVars];
+    KNutAnalog* upsAnalogs[knc::NumberOfVars];
+    };
+
+
 /*********** private vars *******************/
 
   QLabel* m_analogArea;
 
-  struct analogPanelsRecord* m_analogPanels;
+  analogPanelRecordsDef* m_analogPanels;
 
-  struct upsInfo* m_activeUpsInfo; // values for selected ups -- hodnoty pro vybrane ups
-  SettingDataDef* m_settingData;  // v teto strukture jsou ulozeny promene ktere nastavuji konfiguraci
+  KNutVarData::upsInfoDef* m_activeUpsInfo; // values for selected ups -- hodnoty pro vybrane ups
+  KNutVarData::SettingDataDef* m_settingData;  // v teto strukture jsou ulozeny promene ktere nastavuji konfiguraci
 
   KNutVarData* m_analogRecords;
 
