@@ -30,7 +30,7 @@
 #include <qlabel.h>
 #include <qcheckbox.h>
 #include <qspinbox.h>
- 
+
 
 #include <stdio.h>
 //#include <iostream>
@@ -40,11 +40,10 @@
 
 
 
-KNutPrefDlg::KNutPrefDlg(KNutUpsData* const upsData, KNutVarData* const analogData, SettingDataDef* const settingData,
+KNutPrefDlg::KNutPrefDlg(KNutUpsData* const upsData, KNutVarData* const analogData, KNutVarData::SettingDataDef* const settingData,
                           const QString upsName, QWidget* parent,  const char* name, const bool modal)
             :KDialogBase(IconList, i18n("Preferences"),Help|Default|Apply|Ok|Cancel,Ok, parent, name, modal, true),
-                         m_activeUpsName (upsName), m_myUpsData(upsData), m_myAnalogData(analogData), m_prefData(settingData) {
-
+                         m_activeUpsName (upsName), m_myUpsData(upsData), m_myAnalogData(analogData), m_settingData(settingData) {
 
   setName( "UpsMemberDlg" );
 
@@ -168,22 +167,22 @@ void KNutPrefDlg::slotDeleteUps() {
 
 void KNutPrefDlg::slotEditUps() {
   if (m_listBox2->currentItem() != -1)	{
-    upsRecord upsPref;
+    KNutUpsData::upsRecordDef upsRecord;
     // makes dialog
     newUpsDlg = new KNutNewUpsDlg(m_myUpsData,m_myAnalogData,false);
     // reads record
-    m_myUpsData->get(m_listBox2->currentItem(),upsPref);
+    m_myUpsData->get(m_listBox2->currentItem(),upsRecord);
     // sets parameters for edit /  nastavime parametry pro edit
-    newUpsDlg->putData(upsPref);
+    newUpsDlg->putData(upsRecord);
     int result = newUpsDlg->exec();
     if (result == Accepted) {
       // adds into list after OK will be clicked  
       // reads data from form
-      newUpsDlg->getData(upsPref);
+      upsRecord = newUpsDlg->getData();
       // corrects data in list
-      m_myUpsData->put(m_listBox2->currentItem(),upsPref);
+      m_myUpsData->put(m_listBox2->currentItem(),upsRecord);
       // corrects data in window
-      m_listBox2->changeItem(upsPref.name,m_listBox2->currentItem());
+      m_listBox2->changeItem(upsRecord.name,m_listBox2->currentItem());
       m_checked = true;
       // if active UPS is changed, will set checkedActiveUps
       // pokud zmenime aktivni UPS nastavime checkedActiveUps
@@ -195,21 +194,21 @@ void KNutPrefDlg::slotEditUps() {
 
 
 void KNutPrefDlg::slotNewUps () {
-  upsRecord upsPref;
-  // Zalozime novy zdroj
-  // add new power
+  KNutUpsData::upsRecordDef upsRecord;
+  // Zalozime novou UPS
+  // add new UPS
   newUpsDlg = new KNutNewUpsDlg(m_myUpsData,m_myAnalogData);
   int result = newUpsDlg->exec();
   if (result == Accepted) {
     // adds into list, when OK is pressed
     //reads data from form
-    newUpsDlg->getData(upsPref);
+    upsRecord = newUpsDlg->getData();
     //pridame data do zaznamu
     //adds data to record
-    m_myUpsData->add( upsPref);
+    m_myUpsData->add(upsRecord);
     //add data to window
     // pridame data do okenka
-    m_listBox2->insertItem(upsPref.name);
+    m_listBox2->insertItem(upsRecord.name);
     // pokud pridame prvni prekreslime hlavni okno
     // when adds the first sameone, will repaint window
     m_checked = true;
@@ -230,35 +229,46 @@ void KNutPrefDlg::slotApply() {
   unsigned int changeSetting = 0;
 
  // MainPage
-  if (m_prefData->countCols != m_numberOfColumns->value()) {
+  if (m_settingData->countCols != m_numberOfColumns->value()) {
     changeSetting += ChangeCountCols;  // nastavime pocet sloupcu
-    m_prefData->countCols = m_numberOfColumns->value();  // nastavime pocet sloupcu
+    m_settingData->countCols = m_numberOfColumns->value();  // nastavime pocet sloupcu
     }
 
-  if (m_prefData->customBColor != m_checkBoxCbc->isChecked()) {
-    m_prefData->customBColor = m_checkBoxCbc->isChecked();
+  if (m_settingData->customBColor != m_checkBoxCbc->isChecked()) {
+    m_settingData->customBColor = m_checkBoxCbc->isChecked();
     changeSetting += ChangeCustomBColor;
     }
 
-  if (m_prefData->mainBackgroundColor != m_BGButton->color()) {
+  if (m_settingData->mainBackgroundColor != m_BGButton->color()) {
     changeSetting += ChangeMBColor;
-    m_prefData->mainBackgroundColor = m_BGButton->color();  // nastavime barvu pozadi
+    m_settingData->mainBackgroundColor = m_BGButton->color();  // nastavime barvu pozadi
     }
 
   // ovlivnuje jen ukonceni programu, neurcujeme type ChangeSetting
-  if (m_prefData->areYouSure != m_checkBoxAys->isChecked()) {
-    m_prefData->areYouSure = m_checkBoxAys->isChecked();
+  if (m_settingData->areYouSure != m_checkBoxAys->isChecked()) {
+    m_settingData->areYouSure = m_checkBoxAys->isChecked();
     changeSetting = changeSetting | ChangeSomeThing;
     }
 
   //for next start only
-  if (m_prefData->useMainWindow != m_checkBoxMW->isChecked()) {
-    m_prefData->useMainWindow = m_checkBoxMW->isChecked();
+  if (m_comboBoxMainWindow->currentItem() != (int)m_settingData->useMainWindow) {
+    m_settingData->useMainWindow = (KNutVarData::mainWindowStartVariant)m_comboBoxMainWindow->currentItem();
+    changeSetting = changeSetting | ChangeSomeThing;
+   }
+
+//  if (m_prefData->useMainWindow != m_checkBoxMW->isChecked()) {
+//    m_prefData->useMainWindow = m_checkBoxMW->isChecked();
+//    changeSetting = changeSetting | ChangeSomeThing;
+//    }
+  //for next start only
+  if (m_settingData->useMessageWindow != m_checkBoxMesW->isChecked()) {
+    m_settingData->useMessageWindow = m_checkBoxMesW->isChecked();
     changeSetting = changeSetting | ChangeSomeThing;
     }
+
   //for next start only
-  if (m_prefData->useMessageWindow != m_checkBoxMesW->isChecked()) {
-    m_prefData->useMessageWindow = m_checkBoxMesW->isChecked();
+  if (m_settingData->useMessageWindow != m_checkBoxMesW->isChecked()) {
+    m_settingData->useMessageWindow = m_checkBoxMesW->isChecked();
     changeSetting = changeSetting | ChangeSomeThing;
     }
 
@@ -267,21 +277,22 @@ void KNutPrefDlg::slotApply() {
   if ( m_vRadioButton1->isChecked()) newInputVoltage = 230; else newInputVoltage = 120;
   if ( m_fRadioButton1->isChecked()) newInputFrequency = 50; else newInputFrequency = 60;
 
-  if (m_prefData->inputVoltage != newInputVoltage) {
-    m_prefData->inputVoltage = newInputVoltage;
+  if (m_settingData->inputVoltage != newInputVoltage) {
+    m_settingData->inputVoltage = newInputVoltage;
     changeSetting += ChangeVoltage;
     }
 
-  if (m_prefData->inputFrequency != newInputFrequency) {
-    m_prefData->inputFrequency = newInputFrequency;
+  if (m_settingData->inputFrequency != newInputFrequency) {
+    m_settingData->inputFrequency = newInputFrequency;
     changeSetting += ChangeFrequency;
     }
 
- if (m_prefData->lowHighXfer != m_xfer->isChecked()) changeSetting += ChangeXFer;
- m_prefData->lowHighXfer = m_xfer->isChecked();
+ if (m_settingData->lowHighXfer != m_xfer->isChecked()) changeSetting += ChangeXFer;
+   m_settingData->lowHighXfer = m_xfer->isChecked();
 
     //Ups page
   if ( m_checkedActiveUps ) { // zmena aktivni UPS
+    //change of active UPS or add the first UPS, because the first UPS is active always
     changeSetting += ChangeUpsSetting;
     }
   else {
@@ -300,23 +311,22 @@ void KNutPrefDlg::slotApply() {
   if (m_checkBoxFirm->isChecked()) prefPanelFlags += KNutFrontPanel::PBFirm;
   if (m_checkBoxRun->isChecked()) prefPanelFlags += KNutFrontPanel::PBRun;
 
-  if (m_prefData->panelFlags != prefPanelFlags) {
-    m_prefData->panelFlags = prefPanelFlags;
+  if (m_settingData->panelFlags != prefPanelFlags) {
+    m_settingData->panelFlags = prefPanelFlags;
     changeSetting += ChangeMainPanelSetting;
     }
 
-  if (m_prefData->customBPanelColor != m_checkBoxCbpc->isChecked()) {
-    m_prefData->customBPanelColor = m_checkBoxCbpc->isChecked();
+  if (m_settingData->customBPanelColor != m_checkBoxCbpc->isChecked()) {
+    m_settingData->customBPanelColor = m_checkBoxCbpc->isChecked();
     changeSetting += ChangeCustomMPanelBColor;
     }
 
-  if (m_prefData->mPanelBackgroundColor != m_BGPButton->color()) {
+  if (m_settingData->mPanelBackgroundColor != m_BGPButton->color()) {
     changeSetting += ChangeMPBColor;
-    m_prefData->mPanelBackgroundColor = m_BGPButton->color();  // sets color of background
+    m_settingData->mPanelBackgroundColor = m_BGPButton->color();  // sets color of background
     }
 
 
-
     // font Page:
     unsigned int changeFonts;
     changeFonts =0;
@@ -326,13 +336,13 @@ void KNutPrefDlg::slotApply() {
     else
       m_aPanelFont=m_fontWidget->font();
 
-    if ( m_customFont->isChecked() != m_prefData->customFont) {
+    if ( m_customFont->isChecked() != m_settingData->customFont) {
       // zmena typy fontu systemove <-> uzivatelske
-       m_prefData->customFont = m_customFont->isChecked();
-       if (m_prefData->customFont) {
+       m_settingData->customFont = m_customFont->isChecked();
+       if (m_settingData->customFont) {
          // prejdeme na uzivatelske fonty
-         m_prefData->aPanelFont = m_aPanelFont;
-         m_prefData->mPanelFont = m_mPanelFont;
+         m_settingData->aPanelFont = m_aPanelFont;
+         m_settingData->mPanelFont = m_mPanelFont;
          changeSetting += ChangeAnalogFont;
          changeSetting += ChangePanelFont;
          }
@@ -343,52 +353,52 @@ void KNutPrefDlg::slotApply() {
          }
       }
     else {
-      if ( m_prefData->customFont ) {
+      if ( m_settingData->customFont ) {
         // otestujeme zda se zmenili nase fonty
-        if (m_aPanelFont != m_prefData->aPanelFont) {
-          m_prefData->aPanelFont = m_aPanelFont;
+        if (m_aPanelFont != m_settingData->aPanelFont) {
+          m_settingData->aPanelFont = m_aPanelFont;
           changeSetting += ChangeAnalogFont;
           }
-        if (m_mPanelFont != m_prefData->mPanelFont) {
-          m_prefData->mPanelFont = m_mPanelFont;
+        if (m_mPanelFont != m_settingData->mPanelFont) {
+          m_settingData->mPanelFont = m_mPanelFont;
           changeSetting += ChangePanelFont;
           }
         }
       }
   // analog page
 
-  if (m_prefData->customBAnalogColor != m_checkBoxCbac->isChecked()) {
-    m_prefData->customBAnalogColor = m_checkBoxCbac->isChecked();
+  if (m_settingData->customBAnalogColor != m_checkBoxCbac->isChecked()) {
+    m_settingData->customBAnalogColor = m_checkBoxCbac->isChecked();
     changeSetting += ChangeCustomAPanelBColor;
     }
 
-  if (m_prefData->aPanelBackgroundColor != m_BGAButton->color()) {
+  if (m_settingData->aPanelBackgroundColor != m_BGAButton->color()) {
     changeSetting += ChangeAPBColor;
-    m_prefData->aPanelBackgroundColor = m_BGAButton->color();  // nastavime barvu pozadi
+    m_settingData->aPanelBackgroundColor = m_BGAButton->color();  // nastavime barvu pozadi
     }
 
-  if (m_prefData->customOAnalogColor != m_checkBoxCoac->isChecked()) {
-    m_prefData->customOAnalogColor = m_checkBoxCoac->isChecked();
+  if (m_settingData->customOAnalogColor != m_checkBoxCoac->isChecked()) {
+    m_settingData->customOAnalogColor = m_checkBoxCoac->isChecked();
     changeSetting += ChangeCustomAPanelOColor;
     }
 
-  if ((m_prefData->analogFingerColor != m_AFingerButton->color()) ||
-      (m_prefData->analogOKColor != m_AOKButton->color()) ||
-      (m_prefData->analogWarnningColor != m_AWarnningButton->color()) ||
-      (m_prefData->analogErrorColor != m_AErrorButton->color()) ||
-      (m_prefData->analogScaleColor != m_AScaleButton->color()) ||
-      (m_prefData->analogFontColor != m_AFontButton->color())) {
+  if ((m_settingData->analogFingerColor != m_AFingerButton->color()) ||
+      (m_settingData->analogOKColor != m_AOKButton->color()) ||
+      (m_settingData->analogWarnningColor != m_AWarnningButton->color()) ||
+      (m_settingData->analogErrorColor != m_AErrorButton->color()) ||
+      (m_settingData->analogScaleColor != m_AScaleButton->color()) ||
+      (m_settingData->analogFontColor != m_AFontButton->color())) {
     changeSetting += ChangeAPOColor;
-    m_prefData->analogFingerColor = m_AFingerButton->color();  // sets color of pointers-- nastavime barvu rucicky
-    m_prefData->analogOKColor = m_AOKButton->color();  // sets color of OK --  nastavime barvu ok
-    m_prefData->analogWarnningColor = m_AWarnningButton->color();  // nastavime barvu varovano
-    m_prefData->analogErrorColor = m_AErrorButton->color();  // nastavime barvu chyby
-    m_prefData->analogScaleColor = m_AScaleButton->color();  // nastavime barvu stupnice
-    m_prefData->analogFontColor = m_AFontButton->color();  // nastavime barvu textu
+    m_settingData->analogFingerColor = m_AFingerButton->color();  // sets color of pointers-- nastavime barvu rucicky
+    m_settingData->analogOKColor = m_AOKButton->color();  // sets color of OK --  nastavime barvu ok
+    m_settingData->analogWarnningColor = m_AWarnningButton->color();  // nastavime barvu varovano
+    m_settingData->analogErrorColor = m_AErrorButton->color();  // nastavime barvu chyby
+    m_settingData->analogScaleColor = m_AScaleButton->color();  // nastavime barvu stupnice
+    m_settingData->analogFontColor = m_AFontButton->color();  // nastavime barvu textu
     }
 
-  if (m_prefData->typeDigitalProcessing != m_digitalProcesingOfPointers->currentItem()) {
-    m_prefData->typeDigitalProcessing = m_digitalProcesingOfPointers->currentItem();
+  if (m_settingData->typeDigitalProcessing != m_digitalProcesingOfPointers->currentItem()) {
+    m_settingData->typeDigitalProcessing = m_digitalProcesingOfPointers->currentItem();
     changeSetting += ChangeTypeOfDigProcessing;
     }
 
@@ -397,20 +407,20 @@ void KNutPrefDlg::slotApply() {
   int stateKIcon;
   if (m_iconRadioButton1->isChecked()) stateKIcon = KNutDock::pictureKI;
   else stateKIcon = KNutDock::generalKI;
-  if (m_prefData->typeOfKIcon != stateKIcon) {
-    if (m_iconRadioButton1->isChecked()) m_prefData->typeOfKIcon = KNutDock::pictureKI;
-    if (m_iconRadioButton2->isChecked()) m_prefData->typeOfKIcon = KNutDock::generalKI;
+  if (m_settingData->typeOfKIcon != stateKIcon) {
+    if (m_iconRadioButton1->isChecked()) m_settingData->typeOfKIcon = KNutDock::pictureKI;
+    if (m_iconRadioButton2->isChecked()) m_settingData->typeOfKIcon = KNutDock::generalKI;
     changeSetting += ChangeTypeOfKIcon;
     }
 
-  if (m_prefData->customKIconColor != m_checkBoxCbi->isChecked()) {
-    m_prefData->customKIconColor = m_checkBoxCbi->isChecked();
+  if (m_settingData->customKIconColor != m_checkBoxCbi->isChecked()) {
+    m_settingData->customKIconColor = m_checkBoxCbi->isChecked();
     changeSetting += ChangeCustomKIconColor;
     }
 
-  if (m_prefData->kIconBackgroundColor != m_BGIButton->color()) {
+  if (m_settingData->kIconBackgroundColor != m_BGIButton->color()) {
     changeSetting += ChangeKIconBColor;
-    m_prefData->kIconBackgroundColor = m_BGIButton->color();  // nastavime barvu pozadi
+    m_settingData->kIconBackgroundColor = m_BGIButton->color();  // nastavime barvu pozadi
     }
 
   unsigned int prefToolTipFlags = 0;
@@ -422,8 +432,8 @@ void KNutPrefDlg::slotApply() {
   if (m_checkBoxTTCharge->isChecked()) prefToolTipFlags += KNutDock::TTCharge;
   if (m_checkBoxTTLoad->isChecked()) prefToolTipFlags += KNutDock::TTLoad;
 
-  if (m_prefData->toolTipFlags != prefToolTipFlags) {
-    m_prefData->toolTipFlags = prefToolTipFlags;
+  if (m_settingData->toolTipFlags != prefToolTipFlags) {
+    m_settingData->toolTipFlags = prefToolTipFlags;
     changeSetting += ChangeToolTip;
     }
 
@@ -437,8 +447,8 @@ void KNutPrefDlg::slotDefault() {
       m_numberOfColumns->setValue( knc::DefaultCountCols );
       m_BGButton->setColor(DEFAULT_BG_COLOR);
       m_checkBoxAys->setChecked ( false );
-      m_checkBoxMW->setChecked ( true );
       m_checkBoxMesW->setChecked ( false );
+      m_comboBoxMainWindow->setCurrentItem(KNutVarData::mw_no); // sets NO
       m_vRadioButton1->setChecked( true );
       m_fRadioButton1->setChecked( true );
       m_xfer->setChecked( false );
@@ -492,7 +502,10 @@ void KNutPrefDlg::slotDefault() {
 /*********************************************************************************************/
 
 void KNutPrefDlg::initSetting () {
-  QFrame *page = addPage( i18n("Setting"),i18n("Main Setting"),DesktopIcon("misc"));
+  m_mSetPix = UserIcon ("knc_mset");
+
+
+  QFrame *page = addPage( i18n("Setting"),i18n("Main Setting"),m_mSetPix);
   QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
 
   QGroupBox *dataBox = new QGroupBox (page ,"dataBox");
@@ -514,17 +527,20 @@ void KNutPrefDlg::initSetting () {
 
   m_mainBackgroundColorLabel = new QLabel(i18n("Color of background :"),dataBox,"label3");
   m_BGButton = new KColorButton (dataBox);
-  m_BGButton->setColor (m_prefData->mainBackgroundColor);
+  m_BGButton->setColor (m_settingData->mainBackgroundColor);
 
   QLabel *initSettingLabel4 = new QLabel(i18n("Use dialog \"Are you sure\""),dataBox,"m_areYouSureLabel");
   m_checkBoxAys = new QCheckBox ("",dataBox,"checboxays");
 
   QLabel *initSettingLabel5 = new QLabel(i18n("Use Main window when program is started"),dataBox,"initSettingLabel5");
-  m_checkBoxMW = new QCheckBox ("",dataBox,"checboxmv");
+//  m_checkBoxMW = new QCheckBox ("",dataBox,"checboxmv");
 
   QLabel *initSettingLabel6 = new QLabel(i18n("Show message window, when program reports error"),dataBox,"initSettingLabel6");
   m_checkBoxMesW = new QCheckBox ("",dataBox,"checboxer");
-
+  m_comboBoxMainWindow = new KComboBox (dataBox);
+  m_comboBoxMainWindow->insertItem (i18n("Yes"));
+  m_comboBoxMainWindow->insertItem (i18n("No"));
+  m_comboBoxMainWindow->insertItem (i18n("Auto"));
 
 
 
@@ -553,7 +569,7 @@ void KNutPrefDlg::initSetting () {
   dataLayout->addWidget (m_checkBoxAys,3,1);
 
   dataLayout->addWidget (initSettingLabel5,4,0);
-  dataLayout->addWidget (m_checkBoxMW,4,1);
+  dataLayout->addWidget (m_comboBoxMainWindow,4,1);
 
   dataLayout->addWidget (initSettingLabel6,5,0);
   dataLayout->addWidget (m_checkBoxMesW,5,1);
@@ -578,37 +594,38 @@ void KNutPrefDlg::initSetting () {
   setTopLayout->addStretch( 20 );
 
   //sets value
-  m_numberOfColumns->setValue(m_prefData->countCols);
-  m_BGButton->setColor(m_prefData->mainBackgroundColor);  // sets color of backgound
-  m_checkBoxAys->setChecked(m_prefData->areYouSure);
-  m_checkBoxMW->setChecked(m_prefData->useMainWindow);
-  m_checkBoxMesW->setChecked(m_prefData->useMessageWindow);
+  m_numberOfColumns->setValue(m_settingData->countCols);
+  m_BGButton->setColor(m_settingData->mainBackgroundColor);  // sets color of backgound
+  m_checkBoxAys->setChecked(m_settingData->areYouSure);
+  m_checkBoxMesW->setChecked(m_settingData->useMessageWindow);
+  m_comboBoxMainWindow->setCurrentItem(m_settingData->useMainWindow);
 
-  if (m_prefData->inputVoltage == 230)
+  if (m_settingData->inputVoltage == 230)
     m_vRadioButton1->setChecked( true );
   else
     m_vRadioButton2->setChecked( true );
-  if (m_prefData->inputFrequency == 50)
+  if (m_settingData->inputFrequency == 50)
     m_fRadioButton1->setChecked( true );
   else
    m_fRadioButton2->setChecked( true );
 
-  m_xfer->setChecked(m_prefData->lowHighXfer);
-  m_voltageGroup->setEnabled(!m_prefData->lowHighXfer);
-  m_frequencyGroup->setEnabled(!m_prefData->lowHighXfer);
+  m_xfer->setChecked(m_settingData->lowHighXfer);
+  m_voltageGroup->setEnabled(!m_settingData->lowHighXfer);
+  m_frequencyGroup->setEnabled(!m_settingData->lowHighXfer);
   connect (m_xfer,SIGNAL(toggled(bool)),this,SLOT(slotEnableVoltage(bool)));
   connect (m_xfer,SIGNAL(toggled(bool)),this,SLOT(slotEnableFrequency(bool)));
 
 
-  m_checkBoxCbc->setChecked(m_prefData->customBColor); 
-  m_BGButton->setColor(m_prefData->mainBackgroundColor);
-  m_BGButton->setEnabled(m_prefData->customBColor);
-  m_mainBackgroundColorLabel->setEnabled(m_prefData->customBColor);
+  m_checkBoxCbc->setChecked(m_settingData->customBColor); 
+  m_BGButton->setColor(m_settingData->mainBackgroundColor);
+  m_BGButton->setEnabled(m_settingData->customBColor);
+  m_mainBackgroundColorLabel->setEnabled(m_settingData->customBColor);
   connect (m_checkBoxCbc,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBColor(bool)));
   }
 
 void KNutPrefDlg::initUps () {
-  QFrame *page = addPage( i18n("UPS"),i18n("UPS Setting"),DesktopIcon("knutclient"));
+  m_upsesPix = UserIcon ("knc_upses");
+  QFrame *page = addPage( i18n("UPS"),i18n("UPS Setting"),m_upsesPix);
   QHBoxLayout *upsTopLayout = new QHBoxLayout( page, 0, spacingHint (),"upsTopLayout" );
 
   // makes box for names of UPS's / Vytvorime box pro jmena UPS-ek
@@ -645,8 +662,10 @@ void KNutPrefDlg::initUps () {
   }
 
 void KNutPrefDlg::initDock () {
-//  QFrame *page = addPage( i18n("Dock"),i18n("Docking Setting"),DesktopIcon("knutclient"));
-  QFrame *page = addPage( i18n("Dock"),i18n("Docking Setting"),DesktopIcon("kcmkicker"));
+
+  m_dockPix = UserIcon ("knc_dock");
+  QFrame *page = addPage( i18n("Dock bar"),i18n("Docking Setting"),m_dockPix);
+
   QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
 
   QButtonGroup *typeGroup = new QButtonGroup(i18n("Type of dock's showing"),page,"typeGroup");
@@ -667,25 +686,25 @@ void KNutPrefDlg::initDock () {
 
 
   m_checkBoxTTMFR = new QCheckBox (i18n("M&anufacturer"),infoBox);
-  m_checkBoxTTMFR->setChecked((m_prefData->toolTipFlags) & KNutDock::TTMFR);
+  m_checkBoxTTMFR->setChecked((m_settingData->toolTipFlags) & KNutDock::TTMFR);
 
   m_checkBoxTTModel = new QCheckBox (i18n("M&odel"),infoBox);
-  m_checkBoxTTModel->setChecked((m_prefData->toolTipFlags) & KNutDock::TTModel);
+  m_checkBoxTTModel->setChecked((m_settingData->toolTipFlags) & KNutDock::TTModel);
 
   m_checkBoxTTSerial = new QCheckBox (i18n("&Serial"),infoBox);
-  m_checkBoxTTSerial->setChecked((m_prefData->toolTipFlags) & KNutDock::TTSerial);
+  m_checkBoxTTSerial->setChecked((m_settingData->toolTipFlags) & KNutDock::TTSerial);
 
   m_checkBoxTTFirm = new QCheckBox (i18n("&Firm. rev."),infoBox);
-  m_checkBoxTTFirm->setChecked((m_prefData->toolTipFlags) & KNutDock::TTFirm);
+  m_checkBoxTTFirm->setChecked((m_settingData->toolTipFlags) & KNutDock::TTFirm);
 
   m_checkBoxTTRun = new QCheckBox (i18n("&Runtime"),infoBox);
-  m_checkBoxTTRun->setChecked((m_prefData->toolTipFlags) & KNutDock::TTRun);
+  m_checkBoxTTRun->setChecked((m_settingData->toolTipFlags) & KNutDock::TTRun);
 
   m_checkBoxTTCharge = new QCheckBox (i18n("&Battery Charge"),infoBox);
-  m_checkBoxTTCharge->setChecked((m_prefData->toolTipFlags) & KNutDock::TTCharge);
+  m_checkBoxTTCharge->setChecked((m_settingData->toolTipFlags) & KNutDock::TTCharge);
 
   m_checkBoxTTLoad = new QCheckBox (i18n("&UPS Load"),infoBox);
-  m_checkBoxTTLoad->setChecked((m_prefData->toolTipFlags) & KNutDock::TTLoad);
+  m_checkBoxTTLoad->setChecked((m_settingData->toolTipFlags) & KNutDock::TTLoad);
 
 
   m_iconDockLabel = new QLabel(i18n("Use custom icon's background color"),page,"label1");
@@ -698,9 +717,9 @@ void KNutPrefDlg::initDock () {
   typeLayout->addWidget ( m_iconRadioButton1,1,0 );
   typeLayout->addWidget ( m_iconRadioButton2,2,0 );
 
-  if (m_prefData->typeOfKIcon == KNutDock::pictureKI)
+  if (m_settingData->typeOfKIcon == KNutDock::pictureKI)
     m_iconRadioButton1->setChecked( true );
-  if (m_prefData->typeOfKIcon == KNutDock::generalKI)
+  if (m_settingData->typeOfKIcon == KNutDock::generalKI)
     m_iconRadioButton2->setChecked( true );
 
   infoLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
@@ -717,8 +736,8 @@ void KNutPrefDlg::initDock () {
   colorLayout->addWidget (m_dockBackgroundColorLabel,1,0);
   colorLayout->addWidget (m_BGIButton,1,1);
 
-  m_checkBoxCbi->setChecked(m_prefData->customKIconColor);
-  m_BGIButton->setColor(m_prefData->kIconBackgroundColor);
+  m_checkBoxCbi->setChecked(m_settingData->customKIconColor);
+  m_BGIButton->setColor(m_settingData->kIconBackgroundColor);
 //  m_BGIButton->setEnabled(m_prefData->customKIconColor);
 //  m_dockBackgroundColorLabel->setEnabled(m_prefData->customKIconColor);
 
@@ -730,8 +749,8 @@ void KNutPrefDlg::initDock () {
     }
   else {
     m_iconDockLabel->setEnabled(true);
-    m_BGIButton->setEnabled(m_prefData->customKIconColor);
-    m_dockBackgroundColorLabel->setEnabled(m_prefData->customKIconColor);
+    m_BGIButton->setEnabled(m_settingData->customKIconColor);
+    m_dockBackgroundColorLabel->setEnabled(m_settingData->customKIconColor);
     }
 
   setTopLayout->addStretch( 20 );
@@ -743,7 +762,12 @@ void KNutPrefDlg::initDock () {
 
 
 void KNutPrefDlg::initPanel () {
-  QFrame *page = addPage( i18n("Panel"),i18n("Panel Setting"),DesktopIcon("panel_settings"));
+
+  m_panelPix = UserIcon ("knc_panel");
+
+//  QFrame *page = addPage( i18n("Panel"),i18n("Panel Setting"),DesktopIcon("panel_settings"));
+  QFrame *page = addPage( i18n("Panel"),i18n("Panel Setting"),m_panelPix);
+
   QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
 
 
@@ -753,39 +777,39 @@ void KNutPrefDlg::initPanel () {
 
   QGridLayout *colorLayout = new QGridLayout (10,1,spacingHint(),"colorLayout");
   setTopLayout->addLayout(colorLayout);
-  
+
 
   // vytvorime widgety - Nazev Zatrhavaci box
   //makes widgets - name checkbox
   m_checkBoxOver = new QCheckBox (i18n("UPS &Overload"),infoBox);
-  m_checkBoxOver->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBOver);
+  m_checkBoxOver->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBOver);
 
   m_checkBoxBL = new QCheckBox (i18n("UPS &Battery low"),infoBox);
-  m_checkBoxBL->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBBattLow);
+  m_checkBoxBL->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBBattLow);
 
   m_checkBoxRB = new QCheckBox (i18n("R&eplace battery"),infoBox);
-  m_checkBoxRB->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBRepBatt);
+  m_checkBoxRB->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBRepBatt);
 
   m_checkBoxCal = new QCheckBox (i18n("Ups &calibration"),infoBox);
-  m_checkBoxCal->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBCal);
+  m_checkBoxCal->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBCal);
 
   m_checkBoxMFRM = new QCheckBox (i18n("&Manufac. + Model"),infoBox);
-  m_checkBoxMFRM->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBMFRMod);
+  m_checkBoxMFRM->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBMFRMod);
 
   m_checkBoxMFR = new QCheckBox (i18n("M&anufacturer"),infoBox);
-  m_checkBoxMFR->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBMFR);
+  m_checkBoxMFR->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBMFR);
 
   m_checkBoxModel = new QCheckBox (i18n("M&odel"),infoBox);
-  m_checkBoxModel->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBModel);
+  m_checkBoxModel->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBModel);
 
   m_checkBoxSerial = new QCheckBox (i18n("&Serial"),infoBox);
-  m_checkBoxSerial->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBSerial);
+  m_checkBoxSerial->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBSerial);
 
   m_checkBoxFirm = new QCheckBox (i18n("&Firm. rev."),infoBox);
-  m_checkBoxFirm->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBFirm);
+  m_checkBoxFirm->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBFirm);
 
   m_checkBoxRun = new QCheckBox (i18n("&Runtime"),infoBox);
-  m_checkBoxRun->setChecked((m_prefData->panelFlags) & KNutFrontPanel::PBRun);
+  m_checkBoxRun->setChecked((m_settingData->panelFlags) & KNutFrontPanel::PBRun);
 
 
   QLabel *initPanelLabel1 = new QLabel(i18n("Use custom background color"),page,"label1");
@@ -813,11 +837,11 @@ void KNutPrefDlg::initPanel () {
 
   setTopLayout->addStretch( 20 );
 
-  m_checkBoxCbpc->setChecked(m_prefData->customBPanelColor);
-  m_BGPButton->setColor(m_prefData->mPanelBackgroundColor);
-  m_BGPButton->setEnabled(m_prefData->customBPanelColor);
-  m_panelBackgroundColorLabel->setEnabled(m_prefData->customBPanelColor);
-  m_panelBackgroundColorLabel->setEnabled(m_prefData->customBPanelColor);
+  m_checkBoxCbpc->setChecked(m_settingData->customBPanelColor);
+  m_BGPButton->setColor(m_settingData->mPanelBackgroundColor);
+  m_BGPButton->setEnabled(m_settingData->customBPanelColor);
+  m_panelBackgroundColorLabel->setEnabled(m_settingData->customBPanelColor);
+  m_panelBackgroundColorLabel->setEnabled(m_settingData->customBPanelColor);
   connect (m_checkBoxCbpc,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBPanelColor(bool)));
 
   }
@@ -848,18 +872,20 @@ void KNutPrefDlg::initFonts () {
   setTopLayout->addStretch( 20 );
 
 // init items
-  m_customFont->setChecked(m_prefData->customFont);
-  m_aPanelFont = m_prefData->aPanelFont;
-  m_mPanelFont = m_prefData->mPanelFont;
+  m_customFont->setChecked(m_settingData->customFont);
+  m_aPanelFont = m_settingData->aPanelFont;
+  m_mPanelFont = m_settingData->mPanelFont;
   m_settingFont = MAIN_PANEL_FONT; // sets font for Main Panel /  nastavujeme font pro Main Panel
   m_fontWidget->setFont(m_mPanelFont);
-  m_fontWidget->setEnabled(m_prefData->customFont);
+  m_fontWidget->setEnabled(m_settingData->customFont);
   connect (panelFonts,SIGNAL(activated(int)),this,SLOT(slotChangeSettingFont(int)));
   connect (m_customFont,SIGNAL(toggled(bool)),m_fontWidget,SLOT(setEnabled(bool)));
   }
 
 void KNutPrefDlg::initAnalog () {
-  QFrame *page = addPage( i18n("Analog"),i18n("Setting Analog panel"),DesktopIcon("ksysguard"));
+  m_analogPix = UserIcon ("knc_analog");
+  QFrame *page = addPage( i18n("Analog"),i18n("Setting Analog panel"),m_analogPix);
+//  QFrame *page = addPage( i18n("Analog"),i18n("Setting Analog panel"),DesktopIcon("ksysguard"));
   QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
   QGridLayout *setColorLayout = new QGridLayout( 9,2, spacingHint(),"setColorLayout");
   setTopLayout->addLayout(setColorLayout);
@@ -910,29 +936,29 @@ void KNutPrefDlg::initAnalog () {
   setColorLayout->addWidget ( m_digitalProcesingOfPointers, 9,1);
 
 
-  m_checkBoxCbac->setChecked(m_prefData->customBAnalogColor);
-  m_checkBoxCoac->setChecked(m_prefData->customOAnalogColor);
-  m_BGAButton->setColor(m_prefData->aPanelBackgroundColor);
-  m_BGAButton->setEnabled(m_prefData->customBAnalogColor);
-  m_AFingerButton->setColor(m_prefData->analogFingerColor);
-  m_AFingerButton->setEnabled(m_prefData->customOAnalogColor);
-  m_AOKButton->setColor(m_prefData->analogOKColor);
-  m_AOKButton->setEnabled(m_prefData->customOAnalogColor);
-  m_AWarnningButton->setColor(m_prefData->analogWarnningColor);
-  m_AWarnningButton->setEnabled(m_prefData->customOAnalogColor);
-  m_AErrorButton->setColor(m_prefData->analogErrorColor);
-  m_AErrorButton->setEnabled(m_prefData->customOAnalogColor);
-  m_AScaleButton->setColor(m_prefData->analogScaleColor);
-  m_AScaleButton->setEnabled(m_prefData->customOAnalogColor);
-  m_AFontButton->setColor(m_prefData->analogFontColor);
-  m_AFontButton->setEnabled(m_prefData->customOAnalogColor);
-  m_analogBackgroundColorLabel->setEnabled(m_prefData->customBAnalogColor);
-  m_analogPointerColorLabel->setEnabled(m_prefData->customOAnalogColor);
-  m_analogOKColorLabel->setEnabled(m_prefData->customOAnalogColor);
-  m_analogWarningColorLabel->setEnabled(m_prefData->customOAnalogColor);
-  m_analogErrorColorLabel->setEnabled(m_prefData->customOAnalogColor);
-  m_analogScaleColorLabel->setEnabled(m_prefData->customOAnalogColor);
-  m_analogFontColorLabel->setEnabled(m_prefData->customOAnalogColor);
+  m_checkBoxCbac->setChecked(m_settingData->customBAnalogColor);
+  m_checkBoxCoac->setChecked(m_settingData->customOAnalogColor);
+  m_BGAButton->setColor(m_settingData->aPanelBackgroundColor);
+  m_BGAButton->setEnabled(m_settingData->customBAnalogColor);
+  m_AFingerButton->setColor(m_settingData->analogFingerColor);
+  m_AFingerButton->setEnabled(m_settingData->customOAnalogColor);
+  m_AOKButton->setColor(m_settingData->analogOKColor);
+  m_AOKButton->setEnabled(m_settingData->customOAnalogColor);
+  m_AWarnningButton->setColor(m_settingData->analogWarnningColor);
+  m_AWarnningButton->setEnabled(m_settingData->customOAnalogColor);
+  m_AErrorButton->setColor(m_settingData->analogErrorColor);
+  m_AErrorButton->setEnabled(m_settingData->customOAnalogColor);
+  m_AScaleButton->setColor(m_settingData->analogScaleColor);
+  m_AScaleButton->setEnabled(m_settingData->customOAnalogColor);
+  m_AFontButton->setColor(m_settingData->analogFontColor);
+  m_AFontButton->setEnabled(m_settingData->customOAnalogColor);
+  m_analogBackgroundColorLabel->setEnabled(m_settingData->customBAnalogColor);
+  m_analogPointerColorLabel->setEnabled(m_settingData->customOAnalogColor);
+  m_analogOKColorLabel->setEnabled(m_settingData->customOAnalogColor);
+  m_analogWarningColorLabel->setEnabled(m_settingData->customOAnalogColor);
+  m_analogErrorColorLabel->setEnabled(m_settingData->customOAnalogColor);
+  m_analogScaleColorLabel->setEnabled(m_settingData->customOAnalogColor);
+  m_analogFontColorLabel->setEnabled(m_settingData->customOAnalogColor);
 
 
   m_digitalProcesingOfPointers->insertItem(i18n("Nothing processing"));
@@ -941,7 +967,7 @@ void KNutPrefDlg::initAnalog () {
   m_digitalProcesingOfPointers->insertItem(i18n("Fast antialiasing and blur motion"));
   m_digitalProcesingOfPointers->insertItem(i18n("Fine antialiasing and blur motion"));
 
-  m_digitalProcesingOfPointers->setCurrentItem(m_prefData->typeDigitalProcessing);
+  m_digitalProcesingOfPointers->setCurrentItem(m_settingData->typeDigitalProcessing);
 
 
   connect (m_checkBoxCbac,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBAnalogColor(bool)));
