@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
 
   KAboutData aboutData( "knutclient", I18N_NOOP("KNutClient"),
     VERSION, description, KAboutData::License_GPL,
-    "(c) 2002 - 2008 Daniel Prynych", "Zajecov, Czech Republic", 0, "Daniel at prynych.cz");
+    "(c) 2002 - 2009 Daniel Prynych", "Zajecov, Czech Republic", 0, "Daniel@prynych.cz");
   aboutData.addAuthor("Daniel Prynych",0, "Daniel@prynych.cz","http://www.knut.noveradsl.cz/knutclient/");
   aboutData.addCredit("Arnaud Quette",0,"arnaud.quette@free.fr","http://www.networkupstools.org/");
   aboutData.addCredit("MGE",0,0,"http://opensource.mgeups.com");
@@ -60,17 +60,17 @@ int main(int argc, char *argv[])
   args->clear();
 
  // main KUApp this is remark
-//  if (!KUniqueApplication::start()) {
-//    fprintf(stderr,"Sorry : KNutClient is already running!\n");
-//    exit(0);
-//    }
-//  KUniqueApplication a;
+  if (!KUniqueApplication::start()) {
+    fprintf(stderr,"Sorry : KNutClient is already running!\n");
+    exit(0);
+    }
+  KUniqueApplication a;
 
 //  next line is for testing only.
 //  I don't debug KUniqueApplication 
 
-  KApplication a;
-
+//  KApplication a;
+//
   KNutClient *knutclient = new KNutClient(!noDock);
   int returnCode = a.exec();
   delete knutclient;
